@@ -1,7 +1,10 @@
 #! /usr/bin/env python3
 
 import argparse
-from startcp import functions, printer
+try:
+    import functions, printer
+except Exception:
+    from startcp import functions, printer
 
 
 
@@ -26,6 +29,13 @@ def main():
         help="Generate startcp_config file",
         action="store_true"
     )
+    parser.add_argument(
+        "-v",
+        "--version",
+        default=False,
+        help="Print current version of the startcp-cli",
+        action="store_true"
+    )
 
     args = parser.parse_args()
     functions.run(args)
